# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_firewall_component_dto_result import ApiFirewallComponentDTOResult

class TestApiFirewallComponentDTOResult(unittest.TestCase):
    """ApiFirewallComponentDTOResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiFirewallComponentDTOResult:
        """Test ApiFirewallComponentDTOResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiFirewallComponentDTOResult`
        """
        model = ApiFirewallComponentDTOResult()
        if include_optional:
            return ApiFirewallComponentDTOResult(
                page = 56,
                page_count = 56,
                page_size = 56,
                results = [
                    sonatype_iq_api_client.models.api_firewall_component_dto.ApiFirewallComponentDTO(
                        component_identifier = sonatype_iq_api_client.models.component_identifier.ComponentIdentifier(
                            coordinates = {
                                'key' : ''
                                }, 
                            format = '', ), 
                        date_cleared = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        display_name = '', 
                        hash = '', 
                        match_state = '', 
                        pathname = '', 
                        quarantine_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        quarantine_policy_violations = [
                            sonatype_iq_api_client.models.api_policy_violation_dtov2.ApiPolicyViolationDTOV2(
                                constraint_violations = [
                                    sonatype_iq_api_client.models.api_constraint_violation_dto.ApiConstraintViolationDTO(
                                        constraint_id = '', 
                                        constraint_name = '', 
                                        reasons = [
                                            sonatype_iq_api_client.models.api_constraint_violation_reason_dto.ApiConstraintViolationReasonDTO(
                                                reason = '', 
                                                reference = sonatype_iq_api_client.models.trigger_reference.TriggerReference(
                                                    type = 'SECURITY_VULNERABILITY_REFID', 
                                                    value = '', ), )
                                            ], )
                                    ], 
                                fix_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                legacy_violation_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                open_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                policy_id = '', 
                                policy_name = '', 
                                policy_violation_id = '', 
                                threat_level = 56, 
                                waive_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        quarantined = True, 
                        repository = '', 
                        repository_id = '', )
                    ],
                total = 56
            )
        else:
            return ApiFirewallComponentDTOResult(
        )
        """

    def testApiFirewallComponentDTOResult(self):
        """Test ApiFirewallComponentDTOResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_metrics_reporting_dtov2 import ApiMetricsReportingDTOV2

class TestApiMetricsReportingDTOV2(unittest.TestCase):
    """ApiMetricsReportingDTOV2 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiMetricsReportingDTOV2:
        """Test ApiMetricsReportingDTOV2
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiMetricsReportingDTOV2`
        """
        model = ApiMetricsReportingDTOV2()
        if include_optional:
            return ApiMetricsReportingDTOV2(
                aggregations = [
                    sonatype_iq_api_client.models.api_metrics_reporting_aggregation_dtov2.ApiMetricsReportingAggregationDTOV2(
                        discovered_counts = {
                            'key' : {
                                'key' : 56
                                }
                            }, 
                        evaluation_count = 56, 
                        fixed_counts = {
                            'key' : {
                                'key' : 56
                                }
                            }, 
                        mttr_critical_threat = 56, 
                        mttr_low_threat = 56, 
                        mttr_moderate_threat = 56, 
                        mttr_severe_threat = 56, 
                        open_counts_at_time_period_end = {
                            'key' : {
                                'key' : 56
                                }
                            }, 
                        time_period_start = '', 
                        waived_counts = {
                            'key' : {
                                'key' : 56
                                }
                            }, )
                    ],
                application_id = '',
                application_name = '',
                application_public_id = '',
                organization_id = '',
                organization_name = ''
            )
        else:
            return ApiMetricsReportingDTOV2(
        )
        """

    def testApiMetricsReportingDTOV2(self):
        """Test ApiMetricsReportingDTOV2"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_stale_waiver_dto import ApiStaleWaiverDTO

class TestApiStaleWaiverDTO(unittest.TestCase):
    """ApiStaleWaiverDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiStaleWaiverDTO:
        """Test ApiStaleWaiverDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiStaleWaiverDTO`
        """
        model = ApiStaleWaiverDTO()
        if include_optional:
            return ApiStaleWaiverDTO(
                comment = '',
                constraint_facts = [
                    sonatype_iq_api_client.models.api_constraint_fact_dto.ApiConstraintFactDTO(
                        constraint_id = '', 
                        constraint_name = '', 
                        reasons = [
                            sonatype_iq_api_client.models.api_condition_fact_reason_dto.ApiConditionFactReasonDTO(
                                reason = '', )
                            ], )
                    ],
                create_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                creator_id = '',
                creator_name = '',
                expiry_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                policy_id = '',
                policy_name = '',
                policy_waiver_reason_id = '',
                reason_text = '',
                scope_owner_id = '',
                scope_owner_name = '',
                scope_owner_type = '',
                stale_evaluations = sonatype_iq_api_client.models.api_stale_evaluations_dto.ApiStaleEvaluationsDTO(
                    applications = [
                        sonatype_iq_api_client.models.api_stale_application_evaluation_dto.ApiStaleApplicationEvaluationDTO(
                            application = sonatype_iq_api_client.models.api_application_base_dto.ApiApplicationBaseDTO(
                                contact_user_name = '', 
                                id = '', 
                                name = '', 
                                organization_id = '', 
                                public_id = '', ), 
                            stages = [
                                sonatype_iq_api_client.models.api_stale_evaluation_stage_dto.ApiStaleEvaluationStageDTO(
                                    last_evaluation_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    stage_id = '', )
                                ], )
                        ], 
                    repositories = [
                        sonatype_iq_api_client.models.api_stale_repository_evaluation_dto.ApiStaleRepositoryEvaluationDTO(
                            repository = sonatype_iq_api_client.models.api_repository_dto.ApiRepositoryDTO(
                                audit_enabled = True, 
                                format = '', 
                                namespace_confusion_protection_enabled = True, 
                                policy_compliant_component_selection_enabled = True, 
                                public_id = '', 
                                quarantine_enabled = True, 
                                repository_id = '', 
                                type = '', ), )
                        ], ),
                waiver_id = ''
            )
        else:
            return ApiStaleWaiverDTO(
        )
        """

    def testApiStaleWaiverDTO(self):
        """Test ApiStaleWaiverDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from sonatype_iq_api_client.models.api_composite_value_dto_boolean import ApiCompositeValueDTOBoolean
from sonatype_iq_api_client.models.api_composite_value_dto_integer import ApiCompositeValueDTOInteger
from sonatype_iq_api_client.models.api_composite_value_dto_string import ApiCompositeValueDTOString
from typing import Optional, Set
from typing_extensions import Self

class ApiCompositeSourceControlDTO(BaseModel):
    """
    ApiCompositeSourceControlDTO
    """ # noqa: E501
    base_branch: Optional[ApiCompositeValueDTOString] = Field(default=None, alias="baseBranch")
    close_pr_after_days: Optional[ApiCompositeValueDTOInteger] = Field(default=None, alias="closePrAfterDays")
    close_pr_after_days_open_enabled: Optional[ApiCompositeValueDTOBoolean] = Field(default=None, alias="closePrAfterDaysOpenEnabled")
    close_pr_on_failed_checks_enabled: Optional[ApiCompositeValueDTOBoolean] = Field(default=None, alias="closePrOnFailedChecksEnabled")
    commit_status_enabled: Optional[ApiCompositeValueDTOBoolean] = Field(default=None, alias="commitStatusEnabled")
    id: Optional[StrictStr] = None
    inner_source_automated_updates_enabled: Optional[ApiCompositeValueDTOBoolean] = Field(default=None, alias="innerSourceAutomatedUpdatesEnabled")
    manual_pull_requests_enabled: Optional[ApiCompositeValueDTOBoolean] = Field(default=None, alias="manualPullRequestsEnabled")
    owner_id: Optional[StrictStr] = Field(default=None, alias="ownerId")
    provider: Optional[ApiCompositeValueDTOString] = None
    pull_request_commenting_enabled: Optional[ApiCompositeValueDTOBoolean] = Field(default=None, alias="pullRequestCommentingEnabled")
    remediation_pull_requests_enabled: Optional[ApiCompositeValueDTOBoolean] = Field(default=None, alias="remediationPullRequestsEnabled")
    repository_url: Optional[StrictStr] = Field(default=None, alias="repositoryUrl")
    source_control_evaluations_enabled: Optional[ApiCompositeValueDTOBoolean] = Field(default=None, alias="sourceControlEvaluationsEnabled")
    source_control_scan_target: Optional[ApiCompositeValueDTOString] = Field(default=None, alias="sourceControlScanTarget")
    ssh_enabled: Optional[ApiCompositeValueDTOBoolean] = Field(default=None, alias="sshEnabled")
    status_checks_enabled: Optional[ApiCompositeValueDTOBoolean] = Field(default=None, alias="statusChecksEnabled")
    token: Optional[ApiCompositeValueDTOString] = None
    username: Optional[ApiCompositeValueDTOString] = None
    __properties: ClassVar[List[str]] = ["baseBranch", "closePrAfterDays", "closePrAfterDaysOpenEnabled", "closePrOnFailedChecksEnabled", "commitStatusEnabled", "id", "innerSourceAutomatedUpdatesEnabled", "manualPullRequestsEnabled", "ownerId", "provider", "pullRequestCommentingEnabled", "remediationPullRequestsEnabled", "repositoryUrl", "sourceControlEvaluationsEnabled", "sourceControlScanTarget", "sshEnabled", "statusChecksEnabled", "token", "username"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiCompositeSourceControlDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of base_branch
        if self.base_branch:
            _dict['baseBranch'] = self.base_branch.to_dict()
        # override the default output from pydantic by calling `to_dict()` of close_pr_after_days
        if self.close_pr_after_days:
            _dict['closePrAfterDays'] = self.close_pr_after_days.to_dict()
        # override the default output from pydantic by calling `to_dict()` of close_pr_after_days_open_enabled
        if self.close_pr_after_days_open_enabled:
            _dict['closePrAfterDaysOpenEnabled'] = self.close_pr_after_days_open_enabled.to_dict()
        # override the default output from pydantic by calling `to_dict()` of close_pr_on_failed_checks_enabled
        if self.close_pr_on_failed_checks_enabled:
            _dict['closePrOnFailedChecksEnabled'] = self.close_pr_on_failed_checks_enabled.to_dict()
        # override the default output from pydantic by calling `to_dict()` of commit_status_enabled
        if self.commit_status_enabled:
            _dict['commitStatusEnabled'] = self.commit_status_enabled.to_dict()
        # override the default output from pydantic by calling `to_dict()` of inner_source_automated_updates_enabled
        if self.inner_source_automated_updates_enabled:
            _dict['innerSourceAutomatedUpdatesEnabled'] = self.inner_source_automated_updates_enabled.to_dict()
        # override the default output from pydantic by calling `to_dict()` of manual_pull_requests_enabled
        if self.manual_pull_requests_enabled:
            _dict['manualPullRequestsEnabled'] = self.manual_pull_requests_enabled.to_dict()
        # override the default output from pydantic by calling `to_dict()` of provider
        if self.provider:
            _dict['provider'] = self.provider.to_dict()
        # override the default output from pydantic by calling `to_dict()` of pull_request_commenting_enabled
        if self.pull_request_commenting_enabled:
            _dict['pullRequestCommentingEnabled'] = self.pull_request_commenting_enabled.to_dict()
        # override the default output from pydantic by calling `to_dict()` of remediation_pull_requests_enabled
        if self.remediation_pull_requests_enabled:
            _dict['remediationPullRequestsEnabled'] = self.remediation_pull_requests_enabled.to_dict()
        # override the default output from pydantic by calling `to_dict()` of source_control_evaluations_enabled
        if self.source_control_evaluations_enabled:
            _dict['sourceControlEvaluationsEnabled'] = self.source_control_evaluations_enabled.to_dict()
        # override the default output from pydantic by calling `to_dict()` of source_control_scan_target
        if self.source_control_scan_target:
            _dict['sourceControlScanTarget'] = self.source_control_scan_target.to_dict()
        # override the default output from pydantic by calling `to_dict()` of ssh_enabled
        if self.ssh_enabled:
            _dict['sshEnabled'] = self.ssh_enabled.to_dict()
        # override the default output from pydantic by calling `to_dict()` of status_checks_enabled
        if self.status_checks_enabled:
            _dict['statusChecksEnabled'] = self.status_checks_enabled.to_dict()
        # override the default output from pydantic by calling `to_dict()` of token
        if self.token:
            _dict['token'] = self.token.to_dict()
        # override the default output from pydantic by calling `to_dict()` of username
        if self.username:
            _dict['username'] = self.username.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiCompositeSourceControlDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "baseBranch": ApiCompositeValueDTOString.from_dict(obj["baseBranch"]) if obj.get("baseBranch") is not None else None,
            "closePrAfterDays": ApiCompositeValueDTOInteger.from_dict(obj["closePrAfterDays"]) if obj.get("closePrAfterDays") is not None else None,
            "closePrAfterDaysOpenEnabled": ApiCompositeValueDTOBoolean.from_dict(obj["closePrAfterDaysOpenEnabled"]) if obj.get("closePrAfterDaysOpenEnabled") is not None else None,
            "closePrOnFailedChecksEnabled": ApiCompositeValueDTOBoolean.from_dict(obj["closePrOnFailedChecksEnabled"]) if obj.get("closePrOnFailedChecksEnabled") is not None else None,
            "commitStatusEnabled": ApiCompositeValueDTOBoolean.from_dict(obj["commitStatusEnabled"]) if obj.get("commitStatusEnabled") is not None else None,
            "id": obj.get("id"),
            "innerSourceAutomatedUpdatesEnabled": ApiCompositeValueDTOBoolean.from_dict(obj["innerSourceAutomatedUpdatesEnabled"]) if obj.get("innerSourceAutomatedUpdatesEnabled") is not None else None,
            "manualPullRequestsEnabled": ApiCompositeValueDTOBoolean.from_dict(obj["manualPullRequestsEnabled"]) if obj.get("manualPullRequestsEnabled") is not None else None,
            "ownerId": obj.get("ownerId"),
            "provider": ApiCompositeValueDTOString.from_dict(obj["provider"]) if obj.get("provider") is not None else None,
            "pullRequestCommentingEnabled": ApiCompositeValueDTOBoolean.from_dict(obj["pullRequestCommentingEnabled"]) if obj.get("pullRequestCommentingEnabled") is not None else None,
            "remediationPullRequestsEnabled": ApiCompositeValueDTOBoolean.from_dict(obj["remediationPullRequestsEnabled"]) if obj.get("remediationPullRequestsEnabled") is not None else None,
            "repositoryUrl": obj.get("repositoryUrl"),
            "sourceControlEvaluationsEnabled": ApiCompositeValueDTOBoolean.from_dict(obj["sourceControlEvaluationsEnabled"]) if obj.get("sourceControlEvaluationsEnabled") is not None else None,
            "sourceControlScanTarget": ApiCompositeValueDTOString.from_dict(obj["sourceControlScanTarget"]) if obj.get("sourceControlScanTarget") is not None else None,
            "sshEnabled": ApiCompositeValueDTOBoolean.from_dict(obj["sshEnabled"]) if obj.get("sshEnabled") is not None else None,
            "statusChecksEnabled": ApiCompositeValueDTOBoolean.from_dict(obj["statusChecksEnabled"]) if obj.get("statusChecksEnabled") is not None else None,
            "token": ApiCompositeValueDTOString.from_dict(obj["token"]) if obj.get("token") is not None else None,
            "username": ApiCompositeValueDTOString.from_dict(obj["username"]) if obj.get("username") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.api.policy_violation_details_api import PolicyViolationDetailsApi


class TestPolicyViolationDetailsApi(unittest.TestCase):
    """PolicyViolationDetailsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PolicyViolationDetailsApi()

    def tearDown(self) -> None:
        pass

    def test_get_applicable_auto_waiver(self) -> None:
        """Test case for get_applicable_auto_waiver

        """
        pass

    def test_get_applicable_waiver_requests(self) -> None:
        """Test case for get_applicable_waiver_requests

        """
        pass

    def test_get_applicable_waivers(self) -> None:
        """Test case for get_applicable_waivers

        """
        pass

    def test_get_cross_stage_policy_violation_by_constituent_id(self) -> None:
        """Test case for get_cross_stage_policy_violation_by_constituent_id

        """
        pass

    def test_get_cross_stage_policy_violation_by_id(self) -> None:
        """Test case for get_cross_stage_policy_violation_by_id

        """
        pass

    def test_get_policy_violations(self) -> None:
        """Test case for get_policy_violations

        """
        pass

    def test_get_similar_waivers(self) -> None:
        """Test case for get_similar_waivers

        """
        pass

    def test_get_transitive_policy_violations_by_app_scan_component(self) -> None:
        """Test case for get_transitive_policy_violations_by_app_scan_component

        """
        pass

    def test_get_transitive_policy_violations_by_owner_stage_component(self) -> None:
        """Test case for get_transitive_policy_violations_by_owner_stage_component

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_source_control_dto import ApiSourceControlDTO

class TestApiSourceControlDTO(unittest.TestCase):
    """ApiSourceControlDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiSourceControlDTO:
        """Test ApiSourceControlDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiSourceControlDTO`
        """
        model = ApiSourceControlDTO()
        if include_optional:
            return ApiSourceControlDTO(
                base_branch = '',
                close_pr_after_days = 56,
                close_pr_after_days_open_enabled = True,
                close_pr_on_failed_checks_enabled = True,
                commit_status_enabled = True,
                enable_pull_requests = True,
                enable_status_checks = True,
                id = '',
                inner_source_automated_updates_enabled = True,
                manual_pull_requests_enabled = True,
                owner_id = '',
                provider = '',
                pull_request_commenting_enabled = True,
                remediation_pull_requests_enabled = True,
                repository_url = '',
                source_control_evaluations_enabled = True,
                source_control_scan_target = '',
                ssh_enabled = True,
                status_checks_enabled = True,
                token = '',
                username = ''
            )
        else:
            return ApiSourceControlDTO(
        )
        """

    def testApiSourceControlDTO(self):
        """Test ApiSourceControlDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_composite_source_control_dto import ApiCompositeSourceControlDTO

class TestApiCompositeSourceControlDTO(unittest.TestCase):
    """ApiCompositeSourceControlDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiCompositeSourceControlDTO:
        """Test ApiCompositeSourceControlDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiCompositeSourceControlDTO`
        """
        model = ApiCompositeSourceControlDTO()
        if include_optional:
            return ApiCompositeSourceControlDTO(
                base_branch = sonatype_iq_api_client.models.api_composite_value_dto_string.ApiCompositeValueDTOString(
                    parent_name = '', 
                    parent_value = '', 
                    value = '', ),
                close_pr_after_days = sonatype_iq_api_client.models.api_composite_value_dto_integer.ApiCompositeValueDTOInteger(
                    parent_name = '', 
                    parent_value = 56, 
                    value = 56, ),
                close_pr_after_days_open_enabled = sonatype_iq_api_client.models.api_composite_value_dto_boolean.ApiCompositeValueDTOBoolean(
                    parent_name = '', 
                    parent_value = True, 
                    value = True, ),
                close_pr_on_failed_checks_enabled = sonatype_iq_api_client.models.api_composite_value_dto_boolean.ApiCompositeValueDTOBoolean(
                    parent_name = '', 
                    parent_value = True, 
                    value = True, ),
                commit_status_enabled = sonatype_iq_api_client.models.api_composite_value_dto_boolean.ApiCompositeValueDTOBoolean(
                    parent_name = '', 
                    parent_value = True, 
                    value = True, ),
                id = '',
                inner_source_automated_updates_enabled = sonatype_iq_api_client.models.api_composite_value_dto_boolean.ApiCompositeValueDTOBoolean(
                    parent_name = '', 
                    parent_value = True, 
                    value = True, ),
                manual_pull_requests_enabled = sonatype_iq_api_client.models.api_composite_value_dto_boolean.ApiCompositeValueDTOBoolean(
                    parent_name = '', 
                    parent_value = True, 
                    value = True, ),
                owner_id = '',
                provider = sonatype_iq_api_client.models.api_composite_value_dto_string.ApiCompositeValueDTOString(
                    parent_name = '', 
                    parent_value = '', 
                    value = '', ),
                pull_request_commenting_enabled = sonatype_iq_api_client.models.api_composite_value_dto_boolean.ApiCompositeValueDTOBoolean(
                    parent_name = '', 
                    parent_value = True, 
                    value = True, ),
                remediation_pull_requests_enabled = sonatype_iq_api_client.models.api_composite_value_dto_boolean.ApiCompositeValueDTOBoolean(
                    parent_name = '', 
                    parent_value = True, 
                    value = True, ),
                repository_url = '',
                source_control_evaluations_enabled = sonatype_iq_api_client.models.api_composite_value_dto_boolean.ApiCompositeValueDTOBoolean(
                    parent_name = '', 
                    parent_value = True, 
                    value = True, ),
                source_control_scan_target = sonatype_iq_api_client.models.api_composite_value_dto_string.ApiCompositeValueDTOString(
                    parent_name = '', 
                    parent_value = '', 
                    value = '', ),
                ssh_enabled = sonatype_iq_api_client.models.api_composite_value_dto_boolean.ApiCompositeValueDTOBoolean(
                    parent_name = '', 
                    parent_value = True, 
                    value = True, ),
                status_checks_enabled = sonatype_iq_api_client.models.api_composite_value_dto_boolean.ApiCompositeValueDTOBoolean(
                    parent_name = '', 
                    parent_value = True, 
                    value = True, ),
                token = sonatype_iq_api_client.models.api_composite_value_dto_string.ApiCompositeValueDTOString(
                    parent_name = '', 
                    parent_value = '', 
                    value = '', ),
                username = sonatype_iq_api_client.models.api_composite_value_dto_string.ApiCompositeValueDTOString(
                    parent_name = '', 
                    parent_value = '', 
                    value = '', )
            )
        else:
            return ApiCompositeSourceControlDTO(
        )
        """

    def testApiCompositeSourceControlDTO(self):
        """Test ApiCompositeSourceControlDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.grouping_by_dto import GroupingByDTO

class TestGroupingByDTO(unittest.TestCase):
    """GroupingByDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GroupingByDTO:
        """Test GroupingByDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GroupingByDTO`
        """
        model = GroupingByDTO()
        if include_optional:
            return GroupingByDTO(
                additional_info = '',
                group_by = '',
                group_identifier = 'itemType',
                search_result_item_dtos = [
                    sonatype_iq_api_client.models.search_result_item_dto.SearchResultItemDTO(
                        application_category_color = '', 
                        application_category_description = '', 
                        application_category_id = '', 
                        application_category_name = '', 
                        application_id = '', 
                        application_name = '', 
                        application_public_id = '', 
                        application_version = '', 
                        component_hash = '', 
                        component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                            coordinates = {
                                'key' : ''
                                }, 
                            format = '', ), 
                        component_label_color = '', 
                        component_label_description = '', 
                        component_label_id = '', 
                        component_label_name = '', 
                        component_name = '', 
                        item_type = '', 
                        organization_id = '', 
                        organization_name = '', 
                        policy_evaluation_stage = '', 
                        policy_id = '', 
                        policy_name = '', 
                        policy_threat_category = '', 
                        policy_threat_level = 56, 
                        report_id = '', 
                        result_index = 56, 
                        sbom_specification = '', 
                        vulnerability_description = '', 
                        vulnerability_id = '', 
                        vulnerability_status = '', )
                    ]
            )
        else:
            return GroupingByDTO(
        )
        """

    def testGroupingByDTO(self):
        """Test GroupingByDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_applied_license_overrides_dto import ApiAppliedLicenseOverridesDTO

class TestApiAppliedLicenseOverridesDTO(unittest.TestCase):
    """ApiAppliedLicenseOverridesDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiAppliedLicenseOverridesDTO:
        """Test ApiAppliedLicenseOverridesDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiAppliedLicenseOverridesDTO`
        """
        model = ApiAppliedLicenseOverridesDTO()
        if include_optional:
            return ApiAppliedLicenseOverridesDTO(
                license_overrides_by_owner = [
                    sonatype_iq_api_client.models.license_override_by_owner.LicenseOverrideByOwner(
                        license_override = sonatype_iq_api_client.models.license_override.LicenseOverride(
                            comment = '', 
                            component_identifier = sonatype_iq_api_client.models.component_identifier.ComponentIdentifier(
                                coordinates = {
                                    'key' : ''
                                    }, 
                                format = '', ), 
                            id = '', 
                            license_ids = [
                                ''
                                ], 
                            owner_id = '', 
                            status = 'OPEN', ), 
                        owner_id = '', 
                        owner_name = '', 
                        owner_type = 'application', )
                    ]
            )
        else:
            return ApiAppliedLicenseOverridesDTO(
        )
        """

    def testApiAppliedLicenseOverridesDTO(self):
        """Test ApiAppliedLicenseOverridesDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_license_legal_component_dto import ApiLicenseLegalComponentDTO

class TestApiLicenseLegalComponentDTO(unittest.TestCase):
    """ApiLicenseLegalComponentDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiLicenseLegalComponentDTO:
        """Test ApiLicenseLegalComponentDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiLicenseLegalComponentDTO`
        """
        model = ApiLicenseLegalComponentDTO()
        if include_optional:
            return ApiLicenseLegalComponentDTO(
                component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                    coordinates = {
                        'key' : ''
                        }, 
                    format = '', ),
                display_name = '',
                hash = '',
                license_legal_data = sonatype_iq_api_client.models.api_license_legal_data_dto.ApiLicenseLegalDataDTO(
                    attributions = [
                        sonatype_iq_api_client.models.component_obligation_attribution_dto.ComponentObligationAttributionDTO(
                            component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                                coordinates = {
                                    'key' : ''
                                    }, 
                                format = '', ), 
                            content = '', 
                            id = '', 
                            last_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            last_updated_by_username = '', 
                            obligation_name = '', 
                            owner_id = '', 
                            package_url = '', )
                        ], 
                    component_copyright_id = '', 
                    component_copyright_last_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    component_copyright_last_updated_by_username = '', 
                    component_copyright_scope_owner_id = '', 
                    component_licenses_id = '', 
                    component_licenses_last_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    component_licenses_last_updated_by_username = '', 
                    component_licenses_scope_owner_id = '', 
                    component_notices_id = '', 
                    component_notices_last_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    component_notices_last_updated_by_username = '', 
                    component_notices_scope_owner_id = '', 
                    copyrights = [
                        sonatype_iq_api_client.models.api_license_legal_copyright_dto.ApiLicenseLegalCopyrightDTO(
                            content = '', 
                            id = '', 
                            original_content_hash = '', 
                            status = 'enabled', )
                        ], 
                    declared_licenses = [
                        ''
                        ], 
                    effective_license_status = '', 
                    effective_licenses = [
                        ''
                        ], 
                    highest_effective_license_threat_group = sonatype_iq_api_client.models.api_license_threat_dtov2.ApiLicenseThreatDTOV2(
                        license_threat_group_category = '', 
                        license_threat_group_level = 56, 
                        license_threat_group_name = '', ), 
                    license_files = [
                        sonatype_iq_api_client.models.api_license_legal_file_dto.ApiLicenseLegalFileDTO(
                            content = '', 
                            id = '', 
                            original_content_hash = '', 
                            rel_path = '', 
                            status = 'enabled', )
                        ], 
                    notice_files = [
                        sonatype_iq_api_client.models.api_license_legal_file_dto.ApiLicenseLegalFileDTO(
                            content = '', 
                            id = '', 
                            original_content_hash = '', 
                            rel_path = '', 
                            status = 'enabled', )
                        ], 
                    obligations = [
                        sonatype_iq_api_client.models.api_license_legal_obligation_dto.ApiLicenseLegalObligationDTO(
                            comment = '', 
                            id = '', 
                            last_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            last_updated_by_username = '', 
                            name = '', 
                            owner_id = '', 
                            package_url = '', 
                            status = 'OPEN', )
                        ], 
                    observed_licenses = [
                        ''
                        ], 
                    source_links = [
                        sonatype_iq_api_client.models.legal_source_link_dto.LegalSourceLinkDTO(
                            content = '', 
                            id = '', 
                            original_content = '', 
                            status = 'enabled', )
                        ], ),
                package_url = '',
                stage_scans = [
                    sonatype_iq_api_client.models.api_license_legal_stage_scan_dto.ApiLicenseLegalStageScanDTO(
                        scan_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        scan_id = '', 
                        stage_name = '', )
                    ]
            )
        else:
            return ApiLicenseLegalComponentDTO(
        )
        """

    def testApiLicenseLegalComponentDTO(self):
        """Test ApiLicenseLegalComponentDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_license_legal_component_report_dto import ApiLicenseLegalComponentReportDTO

class TestApiLicenseLegalComponentReportDTO(unittest.TestCase):
    """ApiLicenseLegalComponentReportDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiLicenseLegalComponentReportDTO:
        """Test ApiLicenseLegalComponentReportDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiLicenseLegalComponentReportDTO`
        """
        model = ApiLicenseLegalComponentReportDTO()
        if include_optional:
            return ApiLicenseLegalComponentReportDTO(
                component = sonatype_iq_api_client.models.api_license_legal_component_dto.ApiLicenseLegalComponentDTO(
                    component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                        coordinates = {
                            'key' : ''
                            }, 
                        format = '', ), 
                    display_name = '', 
                    hash = '', 
                    license_legal_data = sonatype_iq_api_client.models.api_license_legal_data_dto.ApiLicenseLegalDataDTO(
                        attributions = [
                            sonatype_iq_api_client.models.component_obligation_attribution_dto.ComponentObligationAttributionDTO(
                                content = '', 
                                id = '', 
                                last_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                last_updated_by_username = '', 
                                obligation_name = '', 
                                owner_id = '', 
                                package_url = '', )
                            ], 
                        component_copyright_id = '', 
                        component_copyright_last_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        component_copyright_last_updated_by_username = '', 
                        component_copyright_scope_owner_id = '', 
                        component_licenses_id = '', 
                        component_licenses_last_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        component_licenses_last_updated_by_username = '', 
                        component_licenses_scope_owner_id = '', 
                        component_notices_id = '', 
                        component_notices_last_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        component_notices_last_updated_by_username = '', 
                        component_notices_scope_owner_id = '', 
                        copyrights = [
                            sonatype_iq_api_client.models.api_license_legal_copyright_dto.ApiLicenseLegalCopyrightDTO(
                                content = '', 
                                id = '', 
                                original_content_hash = '', 
                                status = 'enabled', )
                            ], 
                        declared_licenses = [
                            ''
                            ], 
                        effective_license_status = '', 
                        effective_licenses = [
                            ''
                            ], 
                        highest_effective_license_threat_group = sonatype_iq_api_client.models.api_license_threat_dtov2.ApiLicenseThreatDTOV2(
                            license_threat_group_category = '', 
                            license_threat_group_level = 56, 
                            license_threat_group_name = '', ), 
                        license_files = [
                            sonatype_iq_api_client.models.api_license_legal_file_dto.ApiLicenseLegalFileDTO(
                                content = '', 
                                id = '', 
                                original_content_hash = '', 
                                rel_path = '', 
                                status = 'enabled', )
                            ], 
                        notice_files = [
                            sonatype_iq_api_client.models.api_license_legal_file_dto.ApiLicenseLegalFileDTO(
                                content = '', 
                                id = '', 
                                original_content_hash = '', 
                                rel_path = '', 
                                status = 'enabled', )
                            ], 
                        obligations = [
                            sonatype_iq_api_client.models.api_license_legal_obligation_dto.ApiLicenseLegalObligationDTO(
                                comment = '', 
                                id = '', 
                                last_updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                last_updated_by_username = '', 
                                name = '', 
                                owner_id = '', 
                                package_url = '', 
                                status = 'OPEN', )
                            ], 
                        observed_licenses = [
                            ''
                            ], 
                        source_links = [
                            sonatype_iq_api_client.models.legal_source_link_dto.LegalSourceLinkDTO(
                                content = '', 
                                id = '', 
                                original_content = '', 
                                status = 'enabled', )
                            ], ), 
                    package_url = '', 
                    stage_scans = [
                        sonatype_iq_api_client.models.api_license_legal_stage_scan_dto.ApiLicenseLegalStageScanDTO(
                            scan_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            scan_id = '', 
                            stage_name = '', )
                        ], ),
                license_legal_metadata = [
                    sonatype_iq_api_client.models.api_license_legal_metadata_dto.ApiLicenseLegalMetadataDTO(
                        is_multi = True, 
                        license_id = '', 
                        license_name = '', 
                        license_text = '', 
                        obligations = [
                            sonatype_iq_api_client.models.license_obligation_dto.LicenseObligationDTO(
                                name = '', 
                                obligation_texts = [
                                    ''
                                    ], )
                            ], 
                        single_license_ids = [
                            ''
                            ], 
                        threat_group = sonatype_iq_api_client.models.license_threat_group_dto.LicenseThreatGroupDTO(
                            name = '', 
                            threat_level = 56, ), )
                    ]
            )
        else:
            return ApiLicenseLegalComponentReportDTO(
        )
        """

    def testApiLicenseLegalComponentReportDTO(self):
        """Test ApiLicenseLegalComponentReportDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_search_results_dtov2 import ApiSearchResultsDTOV2

class TestApiSearchResultsDTOV2(unittest.TestCase):
    """ApiSearchResultsDTOV2 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiSearchResultsDTOV2:
        """Test ApiSearchResultsDTOV2
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiSearchResultsDTOV2`
        """
        model = ApiSearchResultsDTOV2()
        if include_optional:
            return ApiSearchResultsDTOV2(
                criteria = sonatype_iq_api_client.models.api_search_criteria_dtov2.ApiSearchCriteriaDTOV2(
                    component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                        coordinates = {
                            'key' : ''
                            }, 
                        format = '', ), 
                    hash = '', 
                    package_url = '', 
                    stage_id = '', ),
                results = [
                    sonatype_iq_api_client.models.api_search_result_dtov2.ApiSearchResultDTOV2(
                        application_id = '', 
                        application_name = '', 
                        component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                            coordinates = {
                                'key' : ''
                                }, 
                            format = '', ), 
                        dependency_data = sonatype_iq_api_client.models.api_dependency_data_dto.ApiDependencyDataDTO(
                            direct_dependency = True, 
                            inner_source = True, 
                            inner_source_data = [
                                sonatype_iq_api_client.models.inner_source_data.InnerSourceData(
                                    inner_source_component_purl = '', 
                                    owner_application_id = '', 
                                    owner_application_name = '', )
                                ], 
                            parent_component_purls = [
                                ''
                                ], ), 
                        hash = '', 
                        package_url = '', 
                        report_html_url = '', 
                        report_url = '', 
                        threat_level = 56, )
                    ]
            )
        else:
            return ApiSearchResultsDTOV2(
        )
        """

    def testApiSearchResultsDTOV2(self):
        """Test ApiSearchResultsDTOV2"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr, field_validator
from typing_extensions import Annotated
from sonatype_iq_api_client.models.api_policy_waiver_request_dto import ApiPolicyWaiverRequestDTO
from sonatype_iq_api_client.models.api_policy_waiver_request_options_dto import ApiPolicyWaiverRequestOptionsDTO
from sonatype_iq_api_client.models.api_policy_waiver_request_review_dto import ApiPolicyWaiverRequestReviewDTO

from sonatype_iq_api_client.api_client import ApiClient, RequestSerialized
from sonatype_iq_api_client.api_response import ApiResponse
from sonatype_iq_api_client.rest import RESTResponseType


class PolicyWaiverRequestsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def add_policy_waiver_request_by_policy_violation_id(
        self,
        owner_type: Annotated[str, Field(strict=True, description="The scope of the policy waiver request. Possible values are application, organization, repository, repository_manager, repository_container.")],
        owner_id: Annotated[StrictStr, Field(description="The id for the ownerType provided above. E.g. applicationId if the ownerType is application.")],
        policy_violation_id: Annotated[StrictStr, Field(description="The policyViolationId for the policy violation on which you want to create a policy waiver request. Use the Policy Violation REST API or Reports REST API to obtain the policyViolationId.")],
        api_policy_waiver_request_options_dto: Annotated[ApiPolicyWaiverRequestOptionsDTO, Field(description="The request JSON can include the fields<ol><li>comment (optional, to indicate the reason of the waiver) default value is null</li><li>matcherStrategy (enumeration, required) can have values DEFAULT, EXACT_COMPONENT, ALL_COMPONENTS, ALL_VERSIONS. DEFAULT will match all components if no hash is provided.</li><li>expiryTime (default null) to set the datetime when the waiver expires.</li><li>expireWhenRemediationAvailable (default false) to expire the waiver when a remediation is available.</li><li>noteToReviewer (optional) to add a note to the reviewer</li></ol>")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiPolicyWaiverRequestDTO:
        """add_policy_waiver_request_by_policy_violation_id

        Use this method to create a policy waiver request.  Permissions required: View IQ Elements

        :param owner_type: The scope of the policy waiver request. Possible values are application, organization, repository, repository_manager, repository_container. (required)
        :type owner_type: str
        :param owner_id: The id for the ownerType provided above. E.g. applicationId if the ownerType is application. (required)
        :type owner_id: str
        :param policy_violation_id: The policyViolationId for the policy violation on which you want to create a policy waiver request. Use the Policy Violation REST API or Reports REST API to obtain the policyViolationId. (required)
        :type policy_violation_id: str
        :param api_policy_waiver_request_options_dto: The request JSON can include the fields<ol><li>comment (optional, to indicate the reason of the waiver) default value is null</li><li>matcherStrategy (enumeration, required) can have values DEFAULT, EXACT_COMPONENT, ALL_COMPONENTS, ALL_VERSIONS. DEFAULT will match all components if no hash is provided.</li><li>expiryTime (default null) to set the datetime when the waiver expires.</li><li>expireWhenRemediationAvailable (default false) to expire the waiver when a remediation is available.</li><li>noteToReviewer (optional) to add a note to the reviewer</li></ol> (required)
        :type api_policy_waiver_request_options_dto: ApiPolicyWaiverRequestOptionsDTO
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_policy_waiver_request_by_policy_violation_id_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            policy_violation_id=policy_violation_id,
            api_policy_waiver_request_options_dto=api_policy_waiver_request_options_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiPolicyWaiverRequestDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def add_policy_waiver_request_by_policy_violation_id_with_http_info(
        self,
        owner_type: Annotated[str, Field(strict=True, description="The scope of the policy waiver request. Possible values are application, organization, repository, repository_manager, repository_container.")],
        owner_id: Annotated[StrictStr, Field(description="The id for the ownerType provided above. E.g. applicationId if the ownerType is application.")],
        policy_violation_id: Annotated[StrictStr, Field(description="The policyViolationId for the policy violation on which you want to create a policy waiver request. Use the Policy Violation REST API or Reports REST API to obtain the policyViolationId.")],
        api_policy_waiver_request_options_dto: Annotated[ApiPolicyWaiverRequestOptionsDTO, Field(description="The request JSON can include the fields<ol><li>comment (optional, to indicate the reason of the waiver) default value is null</li><li>matcherStrategy (enumeration, required) can have values DEFAULT, EXACT_COMPONENT, ALL_COMPONENTS, ALL_VERSIONS. DEFAULT will match all components if no hash is provided.</li><li>expiryTime (default null) to set the datetime when the waiver expires.</li><li>expireWhenRemediationAvailable (default false) to expire the waiver when a remediation is available.</li><li>noteToReviewer (optional) to add a note to the reviewer</li></ol>")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ApiPolicyWaiverRequestDTO]:
        """add_policy_waiver_request_by_policy_violation_id

        Use this method to create a policy waiver request.  Permissions required: View IQ Elements

        :param owner_type: The scope of the policy waiver request. Possible values are application, organization, repository, repository_manager, repository_container. (required)
        :type owner_type: str
        :param owner_id: The id for the ownerType provided above. E.g. applicationId if the ownerType is application. (required)
        :type owner_id: str
        :param policy_violation_id: The policyViolationId for the policy violation on which you want to create a policy waiver request. Use the Policy Violation REST API or Reports REST API to obtain the policyViolationId. (required)
        :type policy_violation_id: str
        :param api_policy_waiver_request_options_dto: The request JSON can include the fields<ol><li>comment (optional, to indicate the reason of the waiver) default value is null</li><li>matcherStrategy (enumeration, required) can have values DEFAULT, EXACT_COMPONENT, ALL_COMPONENTS, ALL_VERSIONS. DEFAULT will match all components if no hash is provided.</li><li>expiryTime (default null) to set the datetime when the waiver expires.</li><li>expireWhenRemediationAvailable (default false) to expire the waiver when a remediation is available.</li><li>noteToReviewer (optional) to add a note to the reviewer</li></ol> (required)
        :type api_policy_waiver_request_options_dto: ApiPolicyWaiverRequestOptionsDTO
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_policy_waiver_request_by_policy_violation_id_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            policy_violation_id=policy_violation_id,
            api_policy_waiver_request_options_dto=api_policy_waiver_request_options_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiPolicyWaiverRequestDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def add_policy_waiver_request_by_policy_violation_id_without_preload_content(
        self,
        owner_type: Annotated[str, Field(strict=True, description="The scope of the policy waiver request. Possible values are application, organization, repository, repository_manager, repository_container.")],
        owner_id: Annotated[StrictStr, Field(description="The id for the ownerType provided above. E.g. applicationId if the ownerType is application.")],
        policy_violation_id: Annotated[StrictStr, Field(description="The policyViolationId for the policy violation on which you want to create a policy waiver request. Use the Policy Violation REST API or Reports REST API to obtain the policyViolationId.")],
        api_policy_waiver_request_options_dto: Annotated[ApiPolicyWaiverRequestOptionsDTO, Field(description="The request JSON can include the fields<ol><li>comment (optional, to indicate the reason of the waiver) default value is null</li><li>matcherStrategy (enumeration, required) can have values DEFAULT, EXACT_COMPONENT, ALL_COMPONENTS, ALL_VERSIONS. DEFAULT will match all components if no hash is provided.</li><li>expiryTime (default null) to set the datetime when the waiver expires.</li><li>expireWhenRemediationAvailable (default false) to expire the waiver when a remediation is available.</li><li>noteToReviewer (optional) to add a note to the reviewer</li></ol>")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """add_policy_waiver_request_by_policy_violation_id

        Use this method to create a policy waiver request.  Permissions required: View IQ Elements

        :param owner_type: The scope of the policy waiver request. Possible values are application, organization, repository, repository_manager, repository_container. (required)
        :type owner_type: str
        :param owner_id: The id for the ownerType provided above. E.g. applicationId if the ownerType is application. (required)
        :type owner_id: str
        :param policy_violation_id: The policyViolationId for the policy violation on which you want to create a policy waiver request. Use the Policy Violation REST API or Reports REST API to obtain the policyViolationId. (required)
        :type policy_violation_id: str
        :param api_policy_waiver_request_options_dto: The request JSON can include the fields<ol><li>comment (optional, to indicate the reason of the waiver) default value is null</li><li>matcherStrategy (enumeration, required) can have values DEFAULT, EXACT_COMPONENT, ALL_COMPONENTS, ALL_VERSIONS. DEFAULT will match all components if no hash is provided.</li><li>expiryTime (default null) to set the datetime when the waiver expires.</li><li>expireWhenRemediationAvailable (default false) to expire the waiver when a remediation is available.</li><li>noteToReviewer (optional) to add a note to the reviewer</li></ol> (required)
        :type api_policy_waiver_request_options_dto: ApiPolicyWaiverRequestOptionsDTO
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_policy_waiver_request_by_policy_violation_id_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            policy_violation_id=policy_violation_id,
            api_policy_waiver_request_options_dto=api_policy_waiver_request_options_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiPolicyWaiverRequestDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _add_policy_waiver_request_by_policy_violation_id_serialize(
        self,
        owner_type,
        owner_id,
        policy_violation_id,
        api_policy_waiver_request_options_dto,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner_type is not None:
            _path_params['ownerType'] = owner_type
        if owner_id is not None:
            _path_params['ownerId'] = owner_id
        if policy_violation_id is not None:
            _path_params['policyViolationId'] = policy_violation_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if api_policy_waiver_request_options_dto is not None:
            _body_params = api_policy_waiver_request_options_dto


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v2/policyWaiverRequests/{ownerType}/{ownerId}/policyViolation/{policyViolationId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_policy_waiver_request(
        self,
        owner_type: Annotated[str, Field(strict=True, description="The scope of the policy waiver request. Possible values are application, organization, repository, repository_manager, repository_container.")],
        owner_id: Annotated[StrictStr, Field(description="The id for the ownerType provided above.")],
        policy_waiver_request_id: Annotated[StrictStr, Field(description="The policyWaiverRequestId for which you want to retrieve the details.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiPolicyWaiverRequestDTO:
        """get_policy_waiver_request

        Use this method to retrieve policy waiver request details for the policyWaiverRequestId specified.  Permissions required: View IQ Elements

        :param owner_type: The scope of the policy waiver request. Possible values are application, organization, repository, repository_manager, repository_container. (required)
        :type owner_type: str
        :param owner_id: The id for the ownerType provided above. (required)
        :type owner_id: str
        :param policy_waiver_request_id: The policyWaiverRequestId for which you want to retrieve the details. (required)
        :type policy_waiver_request_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_policy_waiver_request_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            policy_waiver_request_id=policy_waiver_request_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiPolicyWaiverRequestDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_policy_waiver_request_with_http_info(
        self,
        owner_type: Annotated[str, Field(strict=True, description="The scope of the policy waiver request. Possible values are application, organization, repository, repository_manager, repository_container.")],
        owner_id: Annotated[StrictStr, Field(description="The id for the ownerType provided above.")],
        policy_waiver_request_id: Annotated[StrictStr, Field(description="The policyWaiverRequestId for which you want to retrieve the details.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ApiPolicyWaiverRequestDTO]:
        """get_policy_waiver_request

        Use this method to retrieve policy waiver request details for the policyWaiverRequestId specified.  Permissions required: View IQ Elements

        :param owner_type: The scope of the policy waiver request. Possible values are application, organization, repository, repository_manager, repository_container. (required)
        :type owner_type: str
        :param owner_id: The id for the ownerType provided above. (required)
        :type owner_id: str
        :param policy_waiver_request_id: The policyWaiverRequestId for which you want to retrieve the details. (required)
        :type policy_waiver_request_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_policy_waiver_request_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            policy_waiver_request_id=policy_waiver_request_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiPolicyWaiverRequestDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_policy_waiver_request_without_preload_content(
        self,
        owner_type: Annotated[str, Field(strict=True, description="The scope of the policy waiver request. Possible values are application, organization, repository, repository_manager, repository_container.")],
        owner_id: Annotated[StrictStr, Field(description="The id for the ownerType provided above.")],
        policy_waiver_request_id: Annotated[StrictStr, Field(description="The policyWaiverRequestId for which you want to retrieve the details.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_policy_waiver_request

        Use this method to retrieve policy waiver request details for the policyWaiverRequestId specified.  Permissions required: View IQ Elements

        :param owner_type: The scope of the policy waiver request. Possible values are application, organization, repository, repository_manager, repository_container. (required)
        :type owner_type: str
        :param owner_id: The id for the ownerType provided above. (required)
        :type owner_id: str
        :param policy_waiver_request_id: The policyWaiverRequestId for which you want to retrieve the details. (required)
        :type policy_waiver_request_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_policy_waiver_request_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            policy_waiver_request_id=policy_waiver_request_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiPolicyWaiverRequestDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_policy_waiver_request_serialize(
        self,
        owner_type,
        owner_id,
        policy_waiver_request_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner_type is not None:
            _path_params['ownerType'] = owner_type
        if owner_id is not None:
            _path_params['ownerId'] = owner_id
        if policy_waiver_request_id is not None:
            _path_params['policyWaiverRequestId'] = policy_waiver_request_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v2/policyWaiverRequests/{ownerType}/{ownerId}/{policyWaiverRequestId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def review_policy_waiver_request(
        self,
        owner_type: Annotated[str, Field(strict=True, description="The scope of the policy waiver request. Possible values are application, organization, repository, repository_manager, repository_container.")],
        owner_id: Annotated[StrictStr, Field(description="The id for the ownerType provided above. E.g. applicationId if the ownerType is application.")],
        policy_waiver_request_id: Annotated[StrictStr, Field(description="The policyWaiverRequestId for the policy waiver request to be approved or rejected.")],
        api_policy_waiver_request_review_dto: Annotated[ApiPolicyWaiverRequestReviewDTO, Field(description="The request JSON can include the fields<ol><li>status. Can be APPROVED or REJECTED</li><li>rejectionReason (optional). A text explaining the reason for the rejection., <li>comment (optional, to indicate the reason of the waiver) default value is null</li><li>matcherStrategy (enumeration, required) can have values DEFAULT, EXACT_COMPONENT, ALL_COMPONENTS, ALL_VERSIONS. DEFAULT will match all components if no hash is provided.</li><li>expiryTime (default null) to set the datetime when the waiver expires.</li></ol><li>expireWhenRemediationAvailable (default false) to expire the waiver when a remediation is available.</li>")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiPolicyWaiverRequestDTO:
        """review_policy_waiver_request

        Use this method to approve or reject a policy waiver request.  Permissions required: Waive Policy Violations

        :param owner_type: The scope of the policy waiver request. Possible values are application, organization, repository, repository_manager, repository_container. (required)
        :type owner_type: str
        :param owner_id: The id for the ownerType provided above. E.g. applicationId if the ownerType is application. (required)
        :type owner_id: str
        :param policy_waiver_request_id: The policyWaiverRequestId for the policy waiver request to be approved or rejected. (required)
        :type policy_waiver_request_id: str
        :param api_policy_waiver_request_review_dto: The request JSON can include the fields<ol><li>status. Can be APPROVED or REJECTED</li><li>rejectionReason (optional). A text explaining the reason for the rejection., <li>comment (optional, to indicate the reason of the waiver) default value is null</li><li>matcherStrategy (enumeration, required) can have values DEFAULT, EXACT_COMPONENT, ALL_COMPONENTS, ALL_VERSIONS. DEFAULT will match all components if no hash is provided.</li><li>expiryTime (default null) to set the datetime when the waiver expires.</li></ol><li>expireWhenRemediationAvailable (default false) to expire the waiver when a remediation is available.</li> (required)
        :type api_policy_waiver_request_review_dto: ApiPolicyWaiverRequestReviewDTO
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._review_policy_waiver_request_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            policy_waiver_request_id=policy_waiver_request_id,
            api_policy_waiver_request_review_dto=api_policy_waiver_request_review_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiPolicyWaiverRequestDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def review_policy_waiver_request_with_http_info(
        self,
        owner_type: Annotated[str, Field(strict=True, description="The scope of the policy waiver request. Possible values are application, organization, repository, repository_manager, repository_container.")],
        owner_id: Annotated[StrictStr, Field(description="The id for the ownerType provided above. E.g. applicationId if the ownerType is application.")],
        policy_waiver_request_id: Annotated[StrictStr, Field(description="The policyWaiverRequestId for the policy waiver request to be approved or rejected.")],
        api_policy_waiver_request_review_dto: Annotated[ApiPolicyWaiverRequestReviewDTO, Field(description="The request JSON can include the fields<ol><li>status. Can be APPROVED or REJECTED</li><li>rejectionReason (optional). A text explaining the reason for the rejection., <li>comment (optional, to indicate the reason of the waiver) default value is null</li><li>matcherStrategy (enumeration, required) can have values DEFAULT, EXACT_COMPONENT, ALL_COMPONENTS, ALL_VERSIONS. DEFAULT will match all components if no hash is provided.</li><li>expiryTime (default null) to set the datetime when the waiver expires.</li></ol><li>expireWhenRemediationAvailable (default false) to expire the waiver when a remediation is available.</li>")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ApiPolicyWaiverRequestDTO]:
        """review_policy_waiver_request

        Use this method to approve or reject a policy waiver request.  Permissions required: Waive Policy Violations

        :param owner_type: The scope of the policy waiver request. Possible values are application, organization, repository, repository_manager, repository_container. (required)
        :type owner_type: str
        :param owner_id: The id for the ownerType provided above. E.g. applicationId if the ownerType is application. (required)
        :type owner_id: str
        :param policy_waiver_request_id: The policyWaiverRequestId for the policy waiver request to be approved or rejected. (required)
        :type policy_waiver_request_id: str
        :param api_policy_waiver_request_review_dto: The request JSON can include the fields<ol><li>status. Can be APPROVED or REJECTED</li><li>rejectionReason (optional). A text explaining the reason for the rejection., <li>comment (optional, to indicate the reason of the waiver) default value is null</li><li>matcherStrategy (enumeration, required) can have values DEFAULT, EXACT_COMPONENT, ALL_COMPONENTS, ALL_VERSIONS. DEFAULT will match all components if no hash is provided.</li><li>expiryTime (default null) to set the datetime when the waiver expires.</li></ol><li>expireWhenRemediationAvailable (default false) to expire the waiver when a remediation is available.</li> (required)
        :type api_policy_waiver_request_review_dto: ApiPolicyWaiverRequestReviewDTO
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._review_policy_waiver_request_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            policy_waiver_request_id=policy_waiver_request_id,
            api_policy_waiver_request_review_dto=api_policy_waiver_request_review_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiPolicyWaiverRequestDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def review_policy_waiver_request_without_preload_content(
        self,
        owner_type: Annotated[str, Field(strict=True, description="The scope of the policy waiver request. Possible values are application, organization, repository, repository_manager, repository_container.")],
        owner_id: Annotated[StrictStr, Field(description="The id for the ownerType provided above. E.g. applicationId if the ownerType is application.")],
        policy_waiver_request_id: Annotated[StrictStr, Field(description="The policyWaiverRequestId for the policy waiver request to be approved or rejected.")],
        api_policy_waiver_request_review_dto: Annotated[ApiPolicyWaiverRequestReviewDTO, Field(description="The request JSON can include the fields<ol><li>status. Can be APPROVED or REJECTED</li><li>rejectionReason (optional). A text explaining the reason for the rejection., <li>comment (optional, to indicate the reason of the waiver) default value is null</li><li>matcherStrategy (enumeration, required) can have values DEFAULT, EXACT_COMPONENT, ALL_COMPONENTS, ALL_VERSIONS. DEFAULT will match all components if no hash is provided.</li><li>expiryTime (default null) to set the datetime when the waiver expires.</li></ol><li>expireWhenRemediationAvailable (default false) to expire the waiver when a remediation is available.</li>")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """review_policy_waiver_request

        Use this method to approve or reject a policy waiver request.  Permissions required: Waive Policy Violations

        :param owner_type: The scope of the policy waiver request. Possible values are application, organization, repository, repository_manager, repository_container. (required)
        :type owner_type: str
        :param owner_id: The id for the ownerType provided above. E.g. applicationId if the ownerType is application. (required)
        :type owner_id: str
        :param policy_waiver_request_id: The policyWaiverRequestId for the policy waiver request to be approved or rejected. (required)
        :type policy_waiver_request_id: str
        :param api_policy_waiver_request_review_dto: The request JSON can include the fields<ol><li>status. Can be APPROVED or REJECTED</li><li>rejectionReason (optional). A text explaining the reason for the rejection., <li>comment (optional, to indicate the reason of the waiver) default value is null</li><li>matcherStrategy (enumeration, required) can have values DEFAULT, EXACT_COMPONENT, ALL_COMPONENTS, ALL_VERSIONS. DEFAULT will match all components if no hash is provided.</li><li>expiryTime (default null) to set the datetime when the waiver expires.</li></ol><li>expireWhenRemediationAvailable (default false) to expire the waiver when a remediation is available.</li> (required)
        :type api_policy_waiver_request_review_dto: ApiPolicyWaiverRequestReviewDTO
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._review_policy_waiver_request_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            policy_waiver_request_id=policy_waiver_request_id,
            api_policy_waiver_request_review_dto=api_policy_waiver_request_review_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiPolicyWaiverRequestDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _review_policy_waiver_request_serialize(
        self,
        owner_type,
        owner_id,
        policy_waiver_request_id,
        api_policy_waiver_request_review_dto,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner_type is not None:
            _path_params['ownerType'] = owner_type
        if owner_id is not None:
            _path_params['ownerId'] = owner_id
        if policy_waiver_request_id is not None:
            _path_params['policyWaiverRequestId'] = policy_waiver_request_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if api_policy_waiver_request_review_dto is not None:
            _body_params = api_policy_waiver_request_review_dto


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v2/policyWaiverRequests/{ownerType}/{ownerId}/review/{policyWaiverRequestId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def update_policy_waiver_request(
        self,
        owner_type: Annotated[str, Field(strict=True, description="The scope of the policy waiver request. Possible values are application, organization, repository, repository_manager, repository_container.")],
        owner_id: Annotated[StrictStr, Field(description="The id for the ownerType provided above. E.g. applicationId if the ownerType is application.")],
        policy_waiver_request_id: Annotated[StrictStr, Field(description="The id of the policy waiver request to be updated.")],
        api_policy_waiver_request_options_dto: Annotated[ApiPolicyWaiverRequestOptionsDTO, Field(description="The request JSON can include the fields<ol><li>comment (optional, to indicate the reason of the waiver) default value is null</li><li>matcherStrategy (enumeration, required) can have values DEFAULT, EXACT_COMPONENT, ALL_COMPONENTS, ALL_VERSIONS. DEFAULT will match all components if no hash is provided.</li><li>expiryTime (default null) to set the datetime when the waiver expires.</li><li>expireWhenRemediationAvailable (default false) to expire the waiver when a remediation is available.</li><li>noteToReviewer (optional) to add a note to the reviewer</li></ol>")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiPolicyWaiverRequestDTO:
        """update_policy_waiver_request

        Use this method to update a policy waiver request.  Permissions required: View IQ Elements

        :param owner_type: The scope of the policy waiver request. Possible values are application, organization, repository, repository_manager, repository_container. (required)
        :type owner_type: str
        :param owner_id: The id for the ownerType provided above. E.g. applicationId if the ownerType is application. (required)
        :type owner_id: str
        :param policy_waiver_request_id: The id of the policy waiver request to be updated. (required)
        :type policy_waiver_request_id: str
        :param api_policy_waiver_request_options_dto: The request JSON can include the fields<ol><li>comment (optional, to indicate the reason of the waiver) default value is null</li><li>matcherStrategy (enumeration, required) can have values DEFAULT, EXACT_COMPONENT, ALL_COMPONENTS, ALL_VERSIONS. DEFAULT will match all components if no hash is provided.</li><li>expiryTime (default null) to set the datetime when the waiver expires.</li><li>expireWhenRemediationAvailable (default false) to expire the waiver when a remediation is available.</li><li>noteToReviewer (optional) to add a note to the reviewer</li></ol> (required)
        :type api_policy_waiver_request_options_dto: ApiPolicyWaiverRequestOptionsDTO
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_policy_waiver_request_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            policy_waiver_request_id=policy_waiver_request_id,
            api_policy_waiver_request_options_dto=api_policy_waiver_request_options_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiPolicyWaiverRequestDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def update_policy_waiver_request_with_http_info(
        self,
        owner_type: Annotated[str, Field(strict=True, description="The scope of the policy waiver request. Possible values are application, organization, repository, repository_manager, repository_container.")],
        owner_id: Annotated[StrictStr, Field(description="The id for the ownerType provided above. E.g. applicationId if the ownerType is application.")],
        policy_waiver_request_id: Annotated[StrictStr, Field(description="The id of the policy waiver request to be updated.")],
        api_policy_waiver_request_options_dto: Annotated[ApiPolicyWaiverRequestOptionsDTO, Field(description="The request JSON can include the fields<ol><li>comment (optional, to indicate the reason of the waiver) default value is null</li><li>matcherStrategy (enumeration, required) can have values DEFAULT, EXACT_COMPONENT, ALL_COMPONENTS, ALL_VERSIONS. DEFAULT will match all components if no hash is provided.</li><li>expiryTime (default null) to set the datetime when the waiver expires.</li><li>expireWhenRemediationAvailable (default false) to expire the waiver when a remediation is available.</li><li>noteToReviewer (optional) to add a note to the reviewer</li></ol>")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ApiPolicyWaiverRequestDTO]:
        """update_policy_waiver_request

        Use this method to update a policy waiver request.  Permissions required: View IQ Elements

        :param owner_type: The scope of the policy waiver request. Possible values are application, organization, repository, repository_manager, repository_container. (required)
        :type owner_type: str
        :param owner_id: The id for the ownerType provided above. E.g. applicationId if the ownerType is application. (required)
        :type owner_id: str
        :param policy_waiver_request_id: The id of the policy waiver request to be updated. (required)
        :type policy_waiver_request_id: str
        :param api_policy_waiver_request_options_dto: The request JSON can include the fields<ol><li>comment (optional, to indicate the reason of the waiver) default value is null</li><li>matcherStrategy (enumeration, required) can have values DEFAULT, EXACT_COMPONENT, ALL_COMPONENTS, ALL_VERSIONS. DEFAULT will match all components if no hash is provided.</li><li>expiryTime (default null) to set the datetime when the waiver expires.</li><li>expireWhenRemediationAvailable (default false) to expire the waiver when a remediation is available.</li><li>noteToReviewer (optional) to add a note to the reviewer</li></ol> (required)
        :type api_policy_waiver_request_options_dto: ApiPolicyWaiverRequestOptionsDTO
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_policy_waiver_request_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            policy_waiver_request_id=policy_waiver_request_id,
            api_policy_waiver_request_options_dto=api_policy_waiver_request_options_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiPolicyWaiverRequestDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def update_policy_waiver_request_without_preload_content(
        self,
        owner_type: Annotated[str, Field(strict=True, description="The scope of the policy waiver request. Possible values are application, organization, repository, repository_manager, repository_container.")],
        owner_id: Annotated[StrictStr, Field(description="The id for the ownerType provided above. E.g. applicationId if the ownerType is application.")],
        policy_waiver_request_id: Annotated[StrictStr, Field(description="The id of the policy waiver request to be updated.")],
        api_policy_waiver_request_options_dto: Annotated[ApiPolicyWaiverRequestOptionsDTO, Field(description="The request JSON can include the fields<ol><li>comment (optional, to indicate the reason of the waiver) default value is null</li><li>matcherStrategy (enumeration, required) can have values DEFAULT, EXACT_COMPONENT, ALL_COMPONENTS, ALL_VERSIONS. DEFAULT will match all components if no hash is provided.</li><li>expiryTime (default null) to set the datetime when the waiver expires.</li><li>expireWhenRemediationAvailable (default false) to expire the waiver when a remediation is available.</li><li>noteToReviewer (optional) to add a note to the reviewer</li></ol>")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """update_policy_waiver_request

        Use this method to update a policy waiver request.  Permissions required: View IQ Elements

        :param owner_type: The scope of the policy waiver request. Possible values are application, organization, repository, repository_manager, repository_container. (required)
        :type owner_type: str
        :param owner_id: The id for the ownerType provided above. E.g. applicationId if the ownerType is application. (required)
        :type owner_id: str
        :param policy_waiver_request_id: The id of the policy waiver request to be updated. (required)
        :type policy_waiver_request_id: str
        :param api_policy_waiver_request_options_dto: The request JSON can include the fields<ol><li>comment (optional, to indicate the reason of the waiver) default value is null</li><li>matcherStrategy (enumeration, required) can have values DEFAULT, EXACT_COMPONENT, ALL_COMPONENTS, ALL_VERSIONS. DEFAULT will match all components if no hash is provided.</li><li>expiryTime (default null) to set the datetime when the waiver expires.</li><li>expireWhenRemediationAvailable (default false) to expire the waiver when a remediation is available.</li><li>noteToReviewer (optional) to add a note to the reviewer</li></ol> (required)
        :type api_policy_waiver_request_options_dto: ApiPolicyWaiverRequestOptionsDTO
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_policy_waiver_request_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            policy_waiver_request_id=policy_waiver_request_id,
            api_policy_waiver_request_options_dto=api_policy_waiver_request_options_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiPolicyWaiverRequestDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _update_policy_waiver_request_serialize(
        self,
        owner_type,
        owner_id,
        policy_waiver_request_id,
        api_policy_waiver_request_options_dto,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner_type is not None:
            _path_params['ownerType'] = owner_type
        if owner_id is not None:
            _path_params['ownerId'] = owner_id
        if policy_waiver_request_id is not None:
            _path_params['policyWaiverRequestId'] = policy_waiver_request_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if api_policy_waiver_request_options_dto is not None:
            _body_params = api_policy_waiver_request_options_dto


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/api/v2/policyWaiverRequests/{ownerType}/{ownerId}/{policyWaiverRequestId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )


